( cd opt/kde/lib ; rm -rf libkommanderplugin.so.0 )
( cd opt/kde/lib ; ln -sf libkommanderplugin.so.0.0.0 libkommanderplugin.so.0 )
( cd opt/kde/lib ; rm -rf libkommanderwidgets.so )
( cd opt/kde/lib ; ln -sf libkommanderwidgets.so.0.0.0 libkommanderwidgets.so )
( cd opt/kde/lib ; rm -rf libkommanderwidget.so.0 )
( cd opt/kde/lib ; ln -sf libkommanderwidget.so.0.0.0 libkommanderwidget.so.0 )
( cd opt/kde/lib ; rm -rf libkommanderwidgets.so.0 )
( cd opt/kde/lib ; ln -sf libkommanderwidgets.so.0.0.0 libkommanderwidgets.so.0 )
( cd opt/kde/lib ; rm -rf libkommanderwidget.so )
( cd opt/kde/lib ; ln -sf libkommanderwidget.so.0.0.0 libkommanderwidget.so )
( cd opt/kde/lib ; rm -rf libkommanderplugin.so )
( cd opt/kde/lib ; ln -sf libkommanderplugin.so.0.0.0 libkommanderplugin.so )
( cd opt/kde/share/doc/HTML/en/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/quanta ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kommander ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kommander ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/xsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/xsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfilereplace ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/en/common common )
